-- ProductivityHelpers: ultralight edition (sm-ssc + sm4)
-- Most of these will be defined in sm-ssc already.

-- Blend Modes
Blend = {
		   Normal = 'BlendMode_Normal',
			  Add = 'BlendMode_Add',
		  CopySrc = 'BlendMode_CopySrc',
		AlphaMask = 'BlendMode_AlphaMask',
	AlphaKnockOut = 'BlendMode_AlphaKnockOut',
		 Multiply = 'BlendMode_WeightedMultiply',
		   Invert = 'BlendMode_InvertDest',
		 NoEffect = 'BlendMode_NoEffect',
	-- sm-ssc only:
		 Modulate = SSC and 'BlendMode_Modulate' or 'BlendMode_Normal',
	AlphaMultiply = SSC and 'BlendMode_AlphaMultiply' or 'BlendMode_Normal',
};

-- Health Declarations
-- Used primarily for lifebars.
if not Health then
	Health = {
		Max    = 'HealthState_Hot',
		Alive  = 'HealthState_Alive',
		Danger = 'HealthState_Danger',
		Dead   = 'HealthState_Dead'
	};
end;

--[[ Actor commands for non-sm-ssc versions ]]
if not SSC then
	function Actor:CenterX()
		self:x(SCREEN_CENTER_X);
	end;

	function Actor:CenterY()
		self:y(SCREEN_CENTER_Y);
	end;

	-- xy(actorX,actorY)
	-- Sets the x and y of an actor in one command.
	function Actor:xy(actorX,actorY)
		self:x(actorX);
		self:y(actorY);
	end;
end;

-- MaskSource([clearZBuf])
-- This version of the function lets you decide if you want to clear the
-- z buffer or not, relieving the need for any other helper functions.
function Actor:MaskSource(clearZBuf)
	if not clearZBuf then clearZBuf = false end;
	self:clearzbuffer(clearZBuf);
	self:zwrite(true);
	self:blend('BlendMode_NoEffect');
end;

if not SSC then
	-- MaskDest()
	-- Sets an actor up to be masked by anything with MaskSource().
	function Actor:MaskDest()
		self:ztest(true);
	end;

	-- Thump()
	-- A customized version of pulse that is more appealing for on-beat
	-- effects; unused in ultralight so far (20100203)
	function Actor:thump(fEffectPeriod)
		self:pulse()
		if fEffectPeriod ~= nil then
			self:effecttiming(0,0,0.75*fEffectPeriod,0.25*fEffectPeriod);
		else
			self:effecttiming(0,0,0.75,0.25);
		end
		-- The default effectmagnitude will make this effect look very bad.
		self:effectmagnitude(1,1.125,1);
	end;

	--[[ BitmapText commands ]]

	-- PixelFont()
	-- An alias that turns off texture filtering.
	-- Named because it works best with pixel fonts.
	function BitmapText:PixelFont()
		self:SetTextureFiltering(false);
	end;

	-- Stroke(color)
	-- Sets the text's stroke color.
	function BitmapText:Stroke(c)
		self:strokecolor( c );
	end;

	-- NoStroke()
	-- Removes any stroke.
	function BitmapText:NoStroke()
		self:strokecolor( color("0,0,0,0") );
	end;

	-- Set Text With Format (contributed by Daisuke Master)
	function BitmapText:settextf(...)
		self:settext(string.format(...))
	end

	-- DiffuseAndStroke(diffuse,stroke)
	-- Set diffuse and stroke at the same time.
	function BitmapText:DiffuseAndStroke(diffuseC,strokeC)
		self:diffuse(diffuseC);
		self:strokecolor(strokeC);
	end;
	--[[ end BitmapText commands ]]

	function tobool(v)
		if type(v) == "string" then
			local cmp = string.lower(v);
			if cmp == "true" or cmp == "t" then
				return true;
			elseif cmp == "false" or cmp == "f" then
				return false;
			end;
		elseif type(v) == "number" then
			if v == 0 then return false;
			else return true;
			end;
		end;
	end;
end;

function met(section,metricname)
	return THEME:GetMetric(section,metricname);
end;